@@ -177,6 +177,7 @@ func_query_expander_postgresql(grn_ctx *ctx,
 		{
 			AnyArrayType *synonymsArray;
 			int i, n;
+			int nUsedSynonyms = 0;
 
 			synonymsArray = DatumGetAnyArrayP(synonymsDatum);
 			if (AARR_NDIM(synonymsArray) == 0)
@@ -206,14 +207,33 @@ func_query_expander_postgresql(grn_ctx *ctx,
 									  currentData.synonymsAttribute->attbyval,
 									  currentData.synonymsAttribute->attalign,
 									  &isNULL);
+				if (isNULL)
+				{
+					/* TODO: Reduce log level to GRN_LOG_DEBUG
+					 * in the next release. */
+					GRN_LOG(ctx,
+							GRN_LOG_NOTICE,
+							"[query-expander-postgresql] NULL element exists");
+					continue;
+				}
+				if (!synonymDatum)
+				{
+					/* TODO: Remove this in the next release. */
+					GRN_LOG(ctx,
+							GRN_LOG_NOTICE,
+							"[query-expander-postgresql] "
+							"NULL datum element exists");
+					continue;
+				}
 				synonym = DatumGetTextP(synonymDatum);
-				if (i > 1)
+				if (nUsedSynonyms >= 1)
 					GRN_TEXT_PUTS(ctx, expandedTerm, " OR ");
 				GRN_TEXT_PUTC(ctx, expandedTerm, '(');
 				GRN_TEXT_PUT(ctx, expandedTerm,
 							 VARDATA_ANY(synonym),
 							 VARSIZE_ANY_EXHDR(synonym));
 				GRN_TEXT_PUTC(ctx, expandedTerm, ')');
+				nUsedSynonyms++;
 			}
 		}
 
